@@ -44,18 +44,6 @@ sub render {
 
 __END__
 
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Dancer2::Template::TemplateFlute - Template flute engine for Dancer2
-
-=head1 VERSION
-
-version 0.004
-
 =head1 SYNOPSIS
 
 To use this engine, you may configure L<Dancer2> via C<config.yaml>:
@@ -92,16 +80,3 @@ The extension for the template files. C<html>.
 =head1 SEE ALSO
 
 L<Dancer2>, L<Dancer2::Core::Role::Template>, L<Template::Flute>.
-
-=head1 AUTHOR
-
-William Carr <bill@bottlenose-wine.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by William Carr.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
